@@ -26,6 +26,7 @@ this object structure automatically from a .proto souce file.
 
 """
 
+import sys
 import struct
 from itertools import izip
 
@@ -111,7 +112,7 @@ class Type(object):
 
     @classmethod
     def to_stream(cls,value,stream):
-        """Write a value fo this type to an extprot bytestream."""
+        """Write a value for this type to an extprot bytestream."""
         raise NotImplementedError
 
     @classmethod
@@ -315,40 +316,43 @@ class _TypedList(list):
         items = (self._type.convert(i) for i in items)
         super(_TypedList,self).__init__(items)
 
+    def _store(self,value):
+        return self._type.convert(value)
+
     def __setitem__(self,key,value):
         if isinstance(key,slice):
-            value = (self._type.convert(v) for v in value)
+            value = (self._store(v) for v in value)
         else:
-            value = self._type.convert(value)
+            value = self._store(value)
         super(_TypedList,self).__setitem__(key,value)
 
     def __setslice__(self,i,j,sequence):
-        values = (self._types.convert(v) for v in sequence)
+        values = (self._store(v) for v in sequence)
         super(_TypedList,self).__setslice__(i,j,values)
 
     def __contains__(self,value):
-        value = self._type.convert(value)
-        super(_TypedList,self).__contains__(value)
+        value = self._store(value)
+        return super(_TypedList,self).__contains__(value)
 
     def __iter__(self):
         for i in xrange(len(self)):
             yield self[i]
 
     def append(self,item):
-        return super(_TypedList,self).append(self._type.convert(item))
+        return super(_TypedList,self).append(self._store(item))
 
     def index(self,value,start=None,stop=None):
-        return super(_TypedList,self).index(self._type.convert(item),start,stop)
+        return super(_TypedList,self).index(self._store(item),start,stop)
 
     def extend(self,iterable):
-        items = (self._types.convert(i) for i in iterable)
+        items = (self._store(i) for i in iterable)
         return super(_TypedList,self).extend(items)
 
     def insert(self,index,object):
-        return super(_TypedList,self).insert(index,self._type.convert(object))
+        return super(_TypedList,self).insert(index,self._store(object))
 
     def remove(self,value):
-        return super(_TypedList,self).remove(self._type.convert(value))
+        return super(_TypedList,self).remove(self._store(value))
 
     def __iadd__(self,other):
         return super(_TypedList,self).__iadd__(_TypedList(self._type,other))
@@ -461,8 +465,10 @@ class _UnionMetaclass(type):
                     t_idx += 1
                 #  Adjust __name__ and __module__ to allow pickling
                 if _issubclass(t,Message):
-                    t.__name__ = cls.__name__+"."+t.__name__
-                    t.__module__ = cls.__module__
+                    mod = sys.modules.get(t.__module__)
+                    if getattr(mod,t.__name__,None) is not t:
+                        t.__name__ = cls.__name__+"."+t.__name__
+                        t.__module__ = cls.__module__
         cls._option_from_prefix = {}
         for t in cls._types:
             # TODO: delegate this formatting to the stream somehow?
